# System memory usage increase using CachePolicy=Auto

**URL:** <https://forum.inductiveautomation.com/t/system-memory-usage-increase-using-cachepolicy-auto/17112>\
**Category:** Ignition\
**Created:** [February 23, 2018, 3:04pm UTC](https://forum.inductiveautomation.com/t/system-memory-usage-increase-using-cachepolicy-auto/17112 "2018-02-23T15:04:40Z")\
**Posts on this page:** 3\
**Page:** 1

<div class="post-metadata">

**Author:** ![stefano\_marengo](https://avatars.discourse-cdn.com/v4/letter/s/e36b37/32.png) [@stefano\_marengo](https://forum.inductiveautomation.com/u/stefano_marengo)\
**Post date:** [February 23, 2018, 3:04pm UTC](https://forum.inductiveautomation.com/t/system-memory-usage-increase-using-cachepolicy-auto/17112/1 "2018-02-23T15:04:40Z")

</div>

The memory usage increase each time I open a popup windows using Cache Policy=Auto.  
The issue seem solved switching Cache Policy=Never.

---

<div class="post-metadata">

**Author:** ![pturmel](https://sea1.discourse-cdn.com/inductiveautomation/user_avatar/forum.inductiveautomation.com/pturmel/32/3295_2.png) [@pturmel](https://forum.inductiveautomation.com/u/pturmel)\
**Post date:** [February 23, 2018, 3:08pm UTC](https://forum.inductiveautomation.com/t/system-memory-usage-increase-using-cachepolicy-auto/17112/2 "2018-02-23T15:08:15Z")

</div>

That’s how it’s supposed to work. ‘Auto’ will allow windows to remain in memory so they can open faster the next time you need them. And will automatically throw away such windows if memory consumption starts to push against the limits you set for your client.

---

<div class="post-metadata">

**Author:** ![stefano\_marengo](https://avatars.discourse-cdn.com/v4/letter/s/e36b37/32.png) [@stefano\_marengo](https://forum.inductiveautomation.com/u/stefano_marengo)\
**Post date:** [February 23, 2018, 4:39pm UTC](https://forum.inductiveautomation.com/t/system-memory-usage-increase-using-cachepolicy-auto/17112/3 "2018-02-23T16:39:28Z")

</div>

I tried to reduce the client memory limit from 4096 MB to 2048 MB and actually the system memory is released but after 30-40 times I opening and close the popup windows starts to wait longer opening time.  
If I switch Cache Policy=Never I avoid this issue.
